@@ -51,12 +51,12 @@ my $configure_gnusocial=sub {
    my $region=$_[4]||'';
    my $verified_email=$_[5]||'';
    my $permanent_ip=$_[6]||'';
-   $permanent_ip='' if $permanent_ip=~/Stay/;
+   $permanent_ip='' if $permanent_ip=~/Stay|Reason/;
    if ($permanent_ip=~/Elastic/) {
       my $c="aws ec2 allocate-address --domain vpc";
       my ($hash,$output,$error)=run_aws_cmd($c);
-      $hash||={};$hash->{Addresses}||=[];
-      $permanent_ip=$hash->{Addresses}->{PublicIp}; 
+      $hash||={};
+      $permanent_ip=$hash->{PublicIp}; 
    }
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
    my ($stdout,$stderr)=('','');
@@ -214,10 +214,13 @@ print "\n\n\n\n\n\n\nWE SHOULD HAVE INSTALLED MARIADB=$stdout<==\n\n\n\n\n\n\n";
    ($stdout,$stderr)=$handle->cwd("objs/lib");
    my $pcre='pcre-8.38';
    my $checksum='';
-   ($stdout,$stderr)=$handle->cmd("sudo wget --random-wait --progress=dot ".
-      "ftp://ftp.csx.cam.ac.uk/pub/software/".
-      "programming/pcre/$pcre.tar.gz",'__display__');
-   ($stdout,$stderr)=$handle->cmd("sudo tar xvf $pcre.tar.gz",'__display__');
+   foreach my $cnt (1..3) {
+      ($stdout,$stderr)=$handle->cmd("sudo wget --random-wait --progress=dot ".
+         "ftp://ftp.csx.cam.ac.uk/pub/software/".
+         "programming/pcre/$pcre.tar.gz",'__display__');
+      ($stdout,$stderr)=$handle->cmd("sudo tar xvf $pcre.tar.gz",'__display__');
+      last unless $stderr;
+   }
    my $zlib='zlib-1.2.8';
    ($stdout,$stderr)=$handle->cmd("sudo wget --random-wait --progress=dot ".
       "http://zlib.net/$zlib.tar.gz",'__display__');
